FormStateHelper mixin

Provides functionality to reduce the code required in order to move user input into the ViewModel

Superclass constraints
Mixin applications

Properties

fieldsValidationMessages ↔ Map<String, String?>
getter/setter pair
formValueMap ↔ Map<String, dynamic>
Stores the mapping of the form key to the value entered by the user
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showValidationMessage → bool
no setter
validationMessage → String?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setData(Map<String, dynamic> data) → void
setFormStatus() → void
Called after the formValueMap has been updated and allows you to set values relating to the forms status.
setValidationMessage(String? value) → void
setValidationMessages(Map<String, String?> validationMessages) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited