RedirectRoute class

Inheritance

Constructors

RedirectRoute({required String path, required String redirectTo})
const

Properties

children → List<StackedRoute>?
finalinherited
deferredLoading → bool?
finalinherited
fullMatch → bool
finalinherited
fullscreenDialog → bool?
passed to the fullscreenDialog property in MaterialPageRoute
finalinherited
guards → List<Type>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initial → bool?
finalinherited
maintainState → bool?
passed to the maintainState property in MaterialPageRoute
finalinherited
meta → Map<String, dynamic>
meta data
finalinherited
name → String?
finalinherited
page → Type?
finalinherited
path → String?
route path name which will be assigned to the given variable name const homeScreen = 'path'; if null a kabab cased variable name prefixed with '/' will be used; homeScreen -> home-screen
finalinherited
redirectTo → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usesPathAsKey → bool
if true path is used as page key instead of name
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited