StackedLogger class

Defined the config for the logger in the app

Constructors

StackedLogger({List<Type> loggerOutputs = const [], String logHelperName = 'getLogger', bool disableReleaseConsoleOutput = true, bool disableTestsConsoleOutput = false})
const

Properties

disableReleaseConsoleOutput → bool
When set to true console logs will not be printed in release mode Default is true
final
disableTestsConsoleOutput → bool
When set to true, console logs will not be printed while running unit tests or integration tests
final
hashCode → int
The hash code for this object.
no setterinherited
loggerOutputs → List<Type>
Pass loggerOutputs types here.[StackedLogger(loggerOutputs: CrashlyticsOutput)]
final
logHelperName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited